@@ -12,16 +12,9 @@ testthat::test_that("calendar", {
                 time_by = "2 days")
   cal1 <- calendar(x)
   cal2 <- calendar(y)
-  testthat::expect_equal(cal1,
-                             list_to_tibble(list(time = x)) %>%
-                               add_calendar(time))
   testthat::expect_equal(calendar(x, label = FALSE),
                              cal1 %>%
                                dplyr::select(-all_of(c("month_l", "wday_l"))))
-
-  testthat::expect_equal(cal2,
-                             dplyr::tibble(time = y) %>%
-                               add_calendar(time))
   testthat::expect_equal(calendar(y, label = FALSE),
                              cal2 %>%
                                dplyr::select(-all_of(c("month_l", "wday_l"))))
